@@ -27,7 +27,7 @@
 #include <glib-object.h>
 #include <gio/gio.h>
 
-#include <libtracker-client/tracker-sparql-builder.h>
+#include <libtracker-sparql/tracker-sparql.h>
 
 #include "tracker-miner-object.h"
 
@@ -42,16 +42,15 @@ G_BEGIN_DECLS
 #define TRACKER_IS_MINER_FS_CLASS(c)  (G_TYPE_CHECK_CLASS_TYPE ((c),  TRACKER_TYPE_MINER_FS))
 #define TRACKER_MINER_FS_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), TRACKER_TYPE_MINER_FS, TrackerMinerFSClass))
 
-typedef struct TrackerMinerFS        TrackerMinerFS;
-typedef struct TrackerMinerFSPrivate TrackerMinerFSPrivate;
+typedef struct _TrackerMinerFS        TrackerMinerFS;
+typedef struct _TrackerMinerFSPrivate TrackerMinerFSPrivate;
 
 /**
  * TrackerMinerFS:
  *
- * Abstract miner abstract implementation to get data
- * from the filesystem.
+ * Abstract miner implementation to get data from the filesystem.
  **/
-struct TrackerMinerFS {
+struct _TrackerMinerFS {
 	TrackerMiner parent;
 	TrackerMinerFSPrivate *private;
 };
@@ -59,17 +58,26 @@ struct TrackerMinerFS {
 /**
  * TrackerMinerFSClass:
  * @parent: parent object class
- * @check_file: Called when a file should be checked for further processing
- * @check_directory: Called when a directory should be checked for further processing
- * @check_directory_contents: Called when a directory should be checked for further processing, based on the directory contents.
- * @process_file: Called when the metadata associated to a file is requested.
- * @ignore_next_update_file: Called after a writeback event happens on a file.
- * @monitor_directory: Called to check whether a directory should be modified.
+ * @check_file: Called when a file should be checked for further
+ * processing.
+ * @check_directory: Called when a directory should be checked for
+ * further processing.
+ * @check_directory_contents: Called when a directory should be
+ * checked for further processing, based on the directory contents. 
+ * @process_file: Called when the metadata associated to a file is
+ * requested.
+ * @ignore_next_update_file: Called after a writeback event happens on
+ * a file.
+ * @monitor_directory: Called to check whether a directory should be
+ * modified.
  * @finished: Called when all processing has been performed.
+ * @process_file_attributes: Called when the metadata associated with
+ * a file's attributes changes, for example, the mtime.
  *
- * Prototype for the abstract class, @check_file, @check_directory, @check_directory_contents,
- * @process_file and @monitor_directory must be implemented in the deriving class in order to
- * actually extract data.
+ * Prototype for the abstract class, @check_file, @check_directory,
+ * @check_directory_contents, @process_file and @monitor_directory
+ * must be implemented in the deriving class in order to actually
+ * extract data.
  **/
 typedef struct {
 	TrackerMinerClass parent;
@@ -92,6 +100,10 @@ typedef struct {
 	gboolean (* monitor_directory)        (TrackerMinerFS       *fs,
 	                                       GFile                *file);
 	void     (* finished)                 (TrackerMinerFS       *fs);
+	gboolean (* process_file_attributes)  (TrackerMinerFS       *fs,
+	                                       GFile                *file,
+	                                       TrackerSparqlBuilder *builder,
+	                                       GCancellable         *cancellable);
 } TrackerMinerFSClass;
 
 GType                 tracker_miner_fs_get_type             (void) G_GNUC_CONST;
@@ -102,8 +114,12 @@ gboolean              tracker_miner_fs_directory_remove     (TrackerMinerFS *fs,
                                                              GFile          *file);
 gboolean              tracker_miner_fs_directory_remove_full (TrackerMinerFS *fs,
                                                               GFile          *file);
-void                  tracker_miner_fs_file_add             (TrackerMinerFS *fs,
-                                                             GFile          *file);
+void                  tracker_miner_fs_check_file           (TrackerMinerFS *fs,
+                                                             GFile          *file,
+                                                             gboolean        check_parents);
+void                  tracker_miner_fs_check_directory      (TrackerMinerFS *fs,
+                                                             GFile          *file,
+                                                             gboolean        check_parents);
 void                  tracker_miner_fs_file_notify          (TrackerMinerFS *fs,
                                                              GFile          *file,
                                                              const GError   *error);
