@@ -31,19 +31,18 @@
 #include <libtracker-extract/tracker-extract.h>
 
 #define XMP_MAGIC_TRAILER_LENGTH 256
+#define EXTENSION_RECORD_COMMENT_BLOCK_CODE 0xFE
 
 typedef struct {
 	const gchar *title;
 	const gchar *date;
 	const gchar *artist;
-	gchar *camera;
 } MergeData;
 
 typedef struct {
-	const gchar *width;
-	const gchar *height;
-	const gchar *comment;
-
+	gchar *width;
+	gchar *height;
+	gchar *comment;
 } GifData;
 
 static void extract_gif (const gchar          *filename,
@@ -133,17 +132,17 @@ read_metadata (TrackerSparqlBuilder *preupdate,
 				extBlock.bytes = NULL;
 				extBlock.byteCount = 0;
 
-				if ((status = DGifGetExtension(gifFile, &ExtCode, &ExtData)) != GIF_OK) {
+				if ((status = DGifGetExtension (gifFile, &ExtCode, &ExtData)) != GIF_OK) {
 					g_warning ("Problem getting the extension");
 					return;
 				}
 #if defined(HAVE_EXEMPI)
 				if (ExtData && *ExtData &&
-				    strncmp(&ExtData[1],"XMP Data",8) == 0) {
+				    strncmp (&ExtData[1],"XMP Data",8) == 0) {
 					while (ExtData != NULL && status == GIF_OK ) {
-						if ((status = DGifGetExtensionNext(gifFile, &ExtData)) == GIF_OK) {
+						if ((status = DGifGetExtensionNext (gifFile, &ExtData)) == GIF_OK) {
 							if (ExtData != NULL) {
-								if (ext_block_append(&extBlock, ExtData[0]+1, (char*)&(ExtData[0])) != GIF_OK) {
+								if (ext_block_append (&extBlock, ExtData[0]+1, (char *) &(ExtData[0])) != GIF_OK) {
 									g_warning ("Problem with extension data");
 									return;
 								}
@@ -156,10 +155,37 @@ read_metadata (TrackerSparqlBuilder *preupdate,
 							      uri);
 
 					g_free (extBlock.bytes);
-				} else {
-#else
-				{
+				} else
 #endif
+				/* See Section 24. Comment Extension. in the GIF format definition */
+				if (ExtCode == EXTENSION_RECORD_COMMENT_BLOCK_CODE &&
+				    ExtData && *ExtData) {
+					guint block_count = 0;
+
+					/* Merge all blocks */
+					do {
+						block_count++;
+
+						g_debug ("Comment Extension block found (#%u, %u bytes)",
+						         block_count,
+						         ExtData[0]);
+						if (ext_block_append (&extBlock, ExtData[0], (char *) &(ExtData[1])) != GIF_OK) {
+							g_warning ("Problem with Comment extension data");
+							return;
+						}
+					} while (((status = DGifGetExtensionNext(gifFile, &ExtData)) == GIF_OK) &&
+					         ExtData != NULL);
+
+					/* Add last NUL byte */
+					g_debug ("Comment Extension blocks found (%u) with %u bytes",
+					         block_count,
+					         extBlock.byteCount);
+					extBlock.bytes = g_realloc (extBlock.bytes, extBlock.byteCount + 1);
+					extBlock.bytes[extBlock.byteCount] = '\0';
+
+					/* Set commentt */
+					gd.comment = extBlock.bytes;
+				} else {
 					do {
 						status = DGifGetExtensionNext(gifFile, &ExtData);
 					} while ( status == GIF_OK && ExtData != NULL);
@@ -178,23 +204,10 @@ read_metadata (TrackerSparqlBuilder *preupdate,
 		xd = g_new0 (TrackerXmpData, 1);
 	}
 
-	/* Don't merge if the make is in the model */
-	if ((xd->make == NULL || xd->model == NULL) ||
-	    (xd->make && xd->model && strstr (xd->model, xd->make) == NULL)) {
-		md.camera = tracker_merge_const (" ", 2, xd->make, xd->model);
-	} else {
-		md.camera = g_strdup (xd->model);
-	}
-
 	md.title = tracker_coalesce_strip (3, xd->title, xd->title2, xd->pdf_title);
 	md.date = tracker_coalesce_strip (2, xd->date, xd->time_original);
 	md.artist = tracker_coalesce_strip (2, xd->artist, xd->contributor);
 
-	/* if (gd.comment) { */
-	/* 	tracker_sparql_builder_predicate (metadata, "nie:comment"); */
-	/* 	tracker_sparql_builder_object_unvalidated (metadata, md.comment); */
-	/* } */
-
 	if (xd->license) {
 		tracker_sparql_builder_predicate (metadata, "nie:license");
 		tracker_sparql_builder_object_unvalidated (metadata, xd->license);
@@ -216,10 +229,10 @@ read_metadata (TrackerSparqlBuilder *preupdate,
 		g_free (uri);
 	}
 
-	if (md.date) {
-		tracker_sparql_builder_predicate (metadata, "nie:contentCreated");
-		tracker_sparql_builder_object_unvalidated (metadata, md.date);
-	}
+	tracker_guarantee_date_from_file_mtime (metadata,
+	                                        "nie:contentCreated",
+	                                        md.date,
+	                                        uri);
 
 	if (xd->description) {
 		tracker_sparql_builder_predicate (metadata, "nie:description");
@@ -231,15 +244,36 @@ read_metadata (TrackerSparqlBuilder *preupdate,
 		tracker_sparql_builder_object_unvalidated (metadata, xd->copyright);
 	}
 
-	if (md.title) {
-		tracker_sparql_builder_predicate (metadata, "nie:title");
-		tracker_sparql_builder_object_unvalidated (metadata, md.title);
+	if (xd->make || xd->model) {
+		gchar *equip_uri;
+
+		equip_uri = tracker_sparql_escape_uri_printf ("urn:equipment:%s:%s:",
+		                                              xd->make ? xd->make : "",
+		                                              xd->model ? xd->model : "");
+
+		tracker_sparql_builder_insert_open (preupdate, NULL);
+		tracker_sparql_builder_subject_iri (preupdate, equip_uri);
+		tracker_sparql_builder_predicate (preupdate, "a");
+		tracker_sparql_builder_object (preupdate, "nfo:Equipment");
+
+		if (xd->make) {
+			tracker_sparql_builder_predicate (preupdate, "nfo:manufacturer");
+			tracker_sparql_builder_object_unvalidated (preupdate, xd->make);
+		}
+		if (xd->model) {
+			tracker_sparql_builder_predicate (preupdate, "nfo:model");
+			tracker_sparql_builder_object_unvalidated (preupdate, xd->model);
+		}
+		tracker_sparql_builder_insert_close (preupdate);
+		tracker_sparql_builder_predicate (metadata, "nfo:equipment");
+		tracker_sparql_builder_object_iri (metadata, equip_uri);
+		g_free (equip_uri);
 	}
 
-	if (md.camera) {
-		tracker_sparql_builder_predicate (metadata, "nfo:device");
-		tracker_sparql_builder_object_unvalidated (metadata, md.camera);
-	}
+	tracker_guarantee_title_from_file (metadata,
+	                                   "nie:title",
+	                                   md.title,
+	                                   uri);
 
 	if (md.artist) {
 		gchar *uri = tracker_sparql_escape_uri_printf ("urn:contact:%s", md.artist);
@@ -385,9 +419,11 @@ read_metadata (TrackerSparqlBuilder *preupdate,
 	}
 
 	if (xd->address || xd->country || xd->city) {
+		gchar *addruri;
+
 		tracker_sparql_builder_predicate (metadata, "mlo:location");
 
-		tracker_sparql_builder_object_blank_open (metadata);
+		tracker_sparql_builder_object_blank_open (metadata); /* GeoPoint */
 		tracker_sparql_builder_predicate (metadata, "a");
 		tracker_sparql_builder_object (metadata, "mlo:GeoPoint");
 
@@ -411,21 +447,64 @@ read_metadata (TrackerSparqlBuilder *preupdate,
 			tracker_sparql_builder_object_unvalidated (metadata, xd->country);
 		}
 
-		tracker_sparql_builder_object_blank_close (metadata);
+		addruri = tracker_sparql_get_uuid_urn ();
+
+		tracker_sparql_builder_predicate (metadata, "mlo:asPostalAddress");
+		tracker_sparql_builder_object_iri (metadata, addruri);
+
+		tracker_sparql_builder_object_blank_close (metadata); /* GeoPoint */
+
+		tracker_sparql_builder_insert_open (preupdate, NULL);
+		tracker_sparql_builder_subject_iri (preupdate, addruri);
+
+		g_free (addruri);
+
+		tracker_sparql_builder_predicate (preupdate, "a");
+		tracker_sparql_builder_object (preupdate, "nco:PostalAddress");
+
+		if (xd->address) {
+			tracker_sparql_builder_predicate (preupdate, "nco:streetAddress");
+			tracker_sparql_builder_object_unvalidated (preupdate, xd->address);
+		}
+
+		if (xd->state) {
+			tracker_sparql_builder_predicate (preupdate, "nco:region");
+			tracker_sparql_builder_object_unvalidated (preupdate, xd->state);
+		}
+
+		if (xd->city) {
+			tracker_sparql_builder_predicate (preupdate, "nco:locality");
+			tracker_sparql_builder_object_unvalidated (preupdate, xd->city);
+		}
+
+		if (xd->country) {
+			tracker_sparql_builder_predicate (preupdate, "nco:country");
+			tracker_sparql_builder_object_unvalidated (preupdate, xd->country);
+		}
+
+		tracker_sparql_builder_insert_close (preupdate);
+
 	}
 
 	if (gd.width) {
 		tracker_sparql_builder_predicate (metadata, "nfo:width");
 		tracker_sparql_builder_object_unvalidated (metadata, gd.width);
+		g_free (gd.width);
 	}
 
 	if (gd.height) {
 		tracker_sparql_builder_predicate (metadata, "nfo:height");
 		tracker_sparql_builder_object_unvalidated (metadata, gd.height);
+		g_free (gd.height);
+	}
+
+	if (gd.comment) {
+		tracker_sparql_builder_predicate (metadata, "nie:comment");
+		tracker_sparql_builder_object_unvalidated (metadata, gd.comment);
+		g_free (gd.comment);
 	}
 
 	tracker_xmp_free (xd);
-	g_free (md.camera);
 }
 
 
@@ -434,11 +513,9 @@ extract_gif (const gchar          *uri,
              TrackerSparqlBuilder *preupdate,
              TrackerSparqlBuilder *metadata)
 {
-	goffset        size;
-
-	GifFileType   *gifFile = NULL;
-
-	gchar         *filename;
+	goffset      size;
+	GifFileType *gifFile = NULL;
+	gchar       *filename;
 
 	filename = g_filename_from_uri (uri, NULL, NULL);
 	size = tracker_file_get_size (filename);
@@ -448,8 +525,8 @@ extract_gif (const gchar          *uri,
 		return;
 	}
 
-	if ( ( gifFile = DGifOpenFileName(filename) ) == NULL) {
-		PrintGifError();
+	if ((gifFile = DGifOpenFileName (filename)) == NULL) {
+		PrintGifError ();
 		return;
 	}
 
@@ -461,8 +538,8 @@ extract_gif (const gchar          *uri,
 
 	read_metadata (preupdate, metadata, gifFile, uri);
 
-	if(DGifCloseFile(gifFile) != GIF_OK) {
-		PrintGifError();
+	if (DGifCloseFile (gifFile) != GIF_OK) {
+		PrintGifError ();
 	}
 
 }
