@@ -121,74 +121,86 @@ read_toc (GooList  *items,
 
 		switch (link_action->getKind()) {
 			case actionGoTo: {
-				guint title_length = item->getTitleLength ();
 				LinkGoTo *gto = dynamic_cast <LinkGoTo *> (link_action);
-				GooString *named_dest = gto->getNamedDest ();
 
-				if (title_length > 0) {
-					gchar *str = unicode_to_char (item->getTitle(),
-					                              title_length);
-					g_string_append_printf (*toc, "%s ", str);
-					g_free (str);
+				if (gto) {
+					guint title_length = item->getTitleLength ();
+					GooString *named_dest = gto->getNamedDest ();
+
+					if (title_length > 0) {
+						gchar *str = unicode_to_char (item->getTitle(),
+						                              title_length);
+						g_string_append_printf (*toc, "%s ", str);
+						g_free (str);
+					}
+
+					if (named_dest)
+						g_string_append_printf (*toc, "%s ", named_dest->getCString ());
 				}
 
-				if (named_dest)
-					g_string_append_printf (*toc, "%s ", named_dest->getCString ());
-
 				break;
 			}
 
 			case actionLaunch: {
-				guint title_length = item->getTitleLength ();
 				LinkLaunch *lan = dynamic_cast <LinkLaunch *> (link_action);
-				GooString *filen, *param;
 
-				filen = lan->getFileName();
-				param = lan->getParams();
+				if (lan) {
+					guint title_length = item->getTitleLength ();
+					GooString *filen, *param;
 
-				if (title_length > 0) {
-					gchar *str = unicode_to_char (item->getTitle(),
-					                              title_length);
-					g_string_append_printf (*toc, "%s ", str);
-					g_free (str);
+					filen = lan->getFileName();
+					param = lan->getParams();
+
+					if (title_length > 0) {
+						gchar *str = unicode_to_char (item->getTitle(),
+						                              title_length);
+						g_string_append_printf (*toc, "%s ", str);
+						g_free (str);
+					}
+
+					if (filen)
+						g_string_append_printf (*toc, "%s ", filen->getCString ());
+
+					if (param)
+						g_string_append_printf (*toc, "%s ", param->getCString ());
 				}
 
-				if (filen)
-					g_string_append_printf (*toc, "%s ", filen->getCString ());
-
-				if (param)
-					g_string_append_printf (*toc, "%s ", param->getCString ());
-
 				break;
 			}
 
 			case actionURI: {
 				LinkURI *uri = dynamic_cast <LinkURI *> (link_action);
-				GooString *muri;
 
-				muri = uri->getURI();
+				if (uri) {
+					GooString *muri;
 
-				if (muri)
-					g_string_append_printf (*toc, "%s ", muri->getCString ());
+					muri = uri->getURI();
+
+					if (muri)
+						g_string_append_printf (*toc, "%s ", muri->getCString ());
+				}
 
 				break;
 			}
 
 			case actionNamed: {
-				guint title_length = item->getTitleLength ();
 				LinkNamed *named = dynamic_cast <LinkNamed *> (link_action);
-				GooString *named_dest = named->getName ();
 
-				if (title_length > 0) {
-					gchar *str = unicode_to_char (item->getTitle(),
-					                              title_length);
-					g_string_append_printf (*toc, "%s ", str);
-					g_free (str);
+				if (named) {
+					GooString *named_dest = named->getName ();
+					guint title_length = item->getTitleLength ();
+
+					if (title_length > 0) {
+						gchar *str = unicode_to_char (item->getTitle(),
+						                              title_length);
+						g_string_append_printf (*toc, "%s ", str);
+						g_free (str);
+					}
+
+					if (named_dest)
+						g_string_append_printf (*toc, "%s ", named_dest->getCString ());
 				}
 
-				if (named_dest)
-					g_string_append_printf (*toc, "%s ", named_dest->getCString ());
-
 				break;
 			}
 
@@ -625,18 +637,29 @@ extract_pdf (const gchar          *uri,
 			}
 
 			if (xd->make || xd->model) {
-				gchar *camera;
+				gchar *equip_uri;
 
-				if ((xd->make == NULL || xd->model == NULL) ||
-					(xd->make && xd->model && strstr (xd->model, xd->make) == NULL)) {
-					camera = tracker_merge_const (" ", 2, xd->make, xd->model);
-				} else {
-					camera = g_strdup (xd->model);
+				equip_uri = tracker_sparql_escape_uri_printf ("urn:equipment:%s:%s:",
+				                                              xd->make ? xd->make : "",
+				                                              xd->model ? xd->model : "");
+
+				tracker_sparql_builder_insert_open (preupdate, NULL);
+				tracker_sparql_builder_subject_iri (preupdate, equip_uri);
+				tracker_sparql_builder_predicate (preupdate, "a");
+				tracker_sparql_builder_object (preupdate, "nfo:Equipment");
+
+				if (xd->make) {
+					tracker_sparql_builder_predicate (preupdate, "nfo:manufacturer");
+					tracker_sparql_builder_object_unvalidated (preupdate, xd->make);
 				}
-
-				tracker_sparql_builder_predicate (metadata, "nfo:device");
-				tracker_sparql_builder_object_unvalidated (metadata, camera);
-				g_free (camera);
+				if (xd->model) {
+					tracker_sparql_builder_predicate (preupdate, "nfo:model");
+					tracker_sparql_builder_object_unvalidated (preupdate, xd->model);
+				}
+				tracker_sparql_builder_insert_close (preupdate);
+				tracker_sparql_builder_predicate (metadata, "nfo:equipment");
+				tracker_sparql_builder_object_iri (metadata, equip_uri);
+				g_free (equip_uri);
 			}
 
 			if (xd->orientation) {
@@ -717,11 +740,13 @@ extract_pdf (const gchar          *uri,
 			}
 
 			if (xd->address || xd->country || xd->city) {
+				gchar *addruri;
+
 				tracker_sparql_builder_predicate (metadata, "mlo:location");
 
 				tracker_sparql_builder_object_blank_open (metadata);
 				tracker_sparql_builder_predicate (metadata, "a");
-				tracker_sparql_builder_object (metadata, "mlo:GeoPoint");
+				tracker_sparql_builder_object (metadata, "mlo:GeoPoint"); /* GeoPoint */
 
 				if (xd->address) {
 					tracker_sparql_builder_predicate (metadata, "mlo:address");
@@ -743,7 +768,42 @@ extract_pdf (const gchar          *uri,
 					tracker_sparql_builder_object_unvalidated (metadata, xd->country);
 				}
 
-				tracker_sparql_builder_object_blank_close (metadata);
+				addruri = tracker_sparql_get_uuid_urn ();
+
+				tracker_sparql_builder_predicate (metadata, "mlo:asPostalAddress");
+				tracker_sparql_builder_object_iri (metadata, addruri);
+
+				tracker_sparql_builder_object_blank_close (metadata); /* GeoPoint */
+
+				tracker_sparql_builder_insert_open (preupdate, NULL);
+				tracker_sparql_builder_subject_iri (preupdate, addruri);
+
+				g_free (addruri);
+
+				tracker_sparql_builder_predicate (preupdate, "a");
+				tracker_sparql_builder_object (preupdate, "nco:PostalAddress");
+
+				if (xd->address) {
+					tracker_sparql_builder_predicate (preupdate, "nco:streetAddress");
+					tracker_sparql_builder_object_unvalidated (preupdate, xd->address);
+				}
+
+				if (xd->state) {
+					tracker_sparql_builder_predicate (preupdate, "nco:region");
+					tracker_sparql_builder_object_unvalidated (preupdate, xd->state);
+				}
+
+				if (xd->city) {
+					tracker_sparql_builder_predicate (preupdate, "nco:locality");
+					tracker_sparql_builder_object_unvalidated (preupdate, xd->city);
+				}
+
+				if (xd->country) {
+					tracker_sparql_builder_predicate (preupdate, "nco:country");
+					tracker_sparql_builder_object_unvalidated (preupdate, xd->country);
+				}
+
+				tracker_sparql_builder_insert_close (preupdate);
 			}
 
 			/* PDF keywords aren't used ATM (why not?) */
